==> steam-runtime-tools_0.20201007.0.tar.gz: s/pressure-vessel/THIRD-PARTY.md <==
Third-party modules
===================

pressure-vessel includes the capsule-capture-libs utility from libcapsule,
which is licensed under [LGPL-2.1-or-later][]. See
libcapsule.txt. Complete source code can be obtained from the
same place as pressure-vessel, or from
<https://gitlab.collabora.com/vivek/libcapsule/>.

pressure-vessel incorporates code from GNOME libglnx, variously licensed
under [LGPL-2.0-or-later][] and [LGPL-2.1-or-later][].
Complete source code can be obtained from the same place as
pressure-vessel, or from <http://repo.steampowered.com/steamrt/>.

pressure-vessel incorporates code from Flatpak, licensed under
[LGPL-2.1-or-later][]. Complete source code can be obtained from the
same place as pressure-vessel, or from
<http://repo.steampowered.com/steamrt/>.

pressure-vessel includes the steam-runtime-tools library and utilities,
which are licensed under the [MIT][] license. See steam-runtime-tools.txt.
Complete source code can be obtained from the same place as pressure-vessel,
or from <http://repo.steampowered.com/steamrt/>.

Binary releases of pressure-vessel include the following third-party
programs and libraries:

- bubblewrap: [LGPL-2.0-or-later][]. See bubblewrap.txt.

- libblkid.so.1, libmount.so.1 from util-linux: [LGPL-2.1-or-later][].
  See util-linux.txt.

- libffi.so.6 from libffi: [MIT][]. See libffi.txt.

- libgio-2.0.so.0, libglib-2.0.so.0, libgobject-2.0.so.0,
  libgmodule-2.0.so.0 from GLib: [LGPL-2.1-or-later][].
  See glib2.0.txt.

- libcap.so.2 from libcap: dual-licensed under [GPL-2.0-only][] and
  a [BSD-3-Clause][] variant. See libcap2.txt.

- libelf.so.1 from Red Hat elfutils: [GPL-2.0-or-later][] with linking
  exception. See elfutils.txt.

- libuuid.so.1 from util-linux: [BSD-3-Clause][]. See util-linux.txt.

- libXau.so.6 from Xorg: [MIT][]. See libxau.txt.

- libselinux.so.1 from SELinux: public-domain with [GPL-2.0-only][]
  parts. See libselinux.txt.

- libpcre.so.3 from PCRE: [BSD-3-Clause][]. See pcre3.txt.

- libz.so.1 from zlib: [Zlib][] license. See zlib.txt.

- libjson-glib-1.0.so.0 from json-glib: [LGPL-2.0-or-later][]. See
  json-glib.txt.

Complete source code can be obtained from the same place as
pressure-vessel, or from <http://repo.steampowered.com/steamrt/>.

[BSD-3-Clause]: https://spdx.org/licenses/BSD-3-Clause.html
[GPL-2.0-only]: https://spdx.org/licenses/GPL-2.0-only.html
[GPL-2.0-or-later]: https://spdx.org/licenses/GPL-2.0-or-later.html
[LGPL-2.0-or-later]: https://spdx.org/licenses/LGPL-2.0-or-later.html
[LGPL-2.1-or-later]: https://spdx.org/licenses/LGPL-2.1-or-later.html
[MIT]: https://spdx.org/licenses/MIT.html
[Zlib]: https://spdx.org/licenses/Zlib.html

==> steam-runtime-tools_0.20210203.0.tar.gz: s/pressure-vessel/THIRD-PARTY.md <==
Third-party modules
===================

pressure-vessel includes the capsule-capture-libs utility from libcapsule,
which is licensed under [LGPL-2.1-or-later][]. See
libcapsule.txt. Complete source code can be obtained from the
same place as pressure-vessel, or from
<https://gitlab.collabora.com/vivek/libcapsule/>.

pressure-vessel incorporates code from GNOME libglnx, variously licensed
under [LGPL-2.0-or-later][] and [LGPL-2.1-or-later][].
Complete source code can be obtained from the same place as
pressure-vessel, or from
<https://gitlab.steamos.cloud/steamrt/steam-runtime-tools/>.

pressure-vessel incorporates code from Flatpak, licensed under
[LGPL-2.1-or-later][]. Complete source code can be obtained from the
same place as pressure-vessel, or from
<https://gitlab.steamos.cloud/steamrt/steam-runtime-tools/>.

pressure-vessel includes the steam-runtime-tools library and utilities,
which contain code licensed under the [Apache-2.0][], [LGPL-2.1-or-later][]
and [MIT][] licenses. See steam-runtime-tools.txt.
Complete source code can be obtained from the same place as pressure-vessel,
or from <https://gitlab.steamos.cloud/steamrt/steam-runtime-tools/>.

Binary releases of pressure-vessel include the following third-party
programs and libraries:

- bubblewrap: [LGPL-2.0-or-later][]. See bubblewrap.txt.

- libblkid.so.1, libmount.so.1 from util-linux: [LGPL-2.1-or-later][].
  See util-linux.txt.

- libffi.so.6 from libffi: [MIT][]. See libffi.txt.

- libgio-2.0.so.0, libglib-2.0.so.0, libgobject-2.0.so.0,
  libgmodule-2.0.so.0 from GLib: [LGPL-2.1-or-later][].
  See glib2.0.txt.

- libcap.so.2 from libcap: dual-licensed under [GPL-2.0-only][] and
  a [BSD-3-Clause][] variant. See libcap2.txt.

- libelf.so.1 from Red Hat elfutils: [GPL-2.0-or-later][] with linking
  exception. See elfutils.txt.

- libuuid.so.1 from util-linux: [BSD-3-Clause][]. See util-linux.txt.

- libXau.so.6 from Xorg: [MIT][]. See libxau.txt.

- libselinux.so.1 from SELinux: public-domain with [GPL-2.0-only][]
  parts. See libselinux.txt.

- libpcre.so.3 from PCRE: [BSD-3-Clause][]. See pcre3.txt.

- libz.so.1 from zlib: [Zlib][] license. See zlib.txt.

- libjson-glib-1.0.so.0 from json-glib: [LGPL-2.0-or-later][]. See
  json-glib.txt.

- vulkaninfo from Vulkan-Tools: [Apache-2.0][]. See vulkan-tools.txt.

- wflinfo from waffle: [BSD-2-clause][]. See waffle.txt.

Complete source code can be obtained from the same place as
pressure-vessel, or from <https://repo.steampowered.com/steamrt/>
and <https://repo.steampowered.com/steamrt-images-scout/snapshots/>

[Apache-2.0]: https://spdx.org/licenses/Apache-2.0.html
[BSD-2-Clause]: https://spdx.org/licenses/BSD-2-Clause.html
[BSD-3-Clause]: https://spdx.org/licenses/BSD-3-Clause.html
[GPL-2.0-only]: https://spdx.org/licenses/GPL-2.0-only.html
[GPL-2.0-or-later]: https://spdx.org/licenses/GPL-2.0-or-later.html
[LGPL-2.0-or-later]: https://spdx.org/licenses/LGPL-2.0-or-later.html
[LGPL-2.1-or-later]: https://spdx.org/licenses/LGPL-2.1-or-later.html
[MIT]: https://spdx.org/licenses/MIT.html
[Zlib]: https://spdx.org/licenses/Zlib.html
